@@ -1,4 +1,5 @@
-"""from Products.ATContentTypes.content.folder import ATFolder
+"""
+from Products.ATContentTypes.content.folder import ATFolder
 import ZPublisher.BaseRequest
 from monkey import wrap
 
@@ -9,7 +10,4 @@ def publishTraverse(func, *args):
     from zope.app.publication.interfaces import BeforeTraverseEvent
     notify(BeforeTraverseEvent(args[0], args[2]))
     func(*args)
-
- 
-ATFolder.publishTraverse = publishTraverse
 """
\ No newline at end of file
